@@ -856,6 +856,9 @@ var LibraryEmbind = {
   $makeLegalFunctionName: () => { throw new Error('stub function should not be called'); },
   $runDestructors: () => { throw new Error('stub function should not be called'); },
   $createNamedFunction: () => { throw new Error('stub function should not be called'); },
+  $flushPendingDeletes: () => { throw new Error('stub function should not be called'); },
+  $setDelayFunction: () => { throw new Error('stub function should not be called'); },
+  $PureVirtualError: () => { throw new Error('stub function should not be called'); },
 };
 
 #if EMBIND_AOT
