@@ -224,13 +224,13 @@ std::u32string get_literal_u32string() {
 
 void force_memory_growth() {
   std::size_t old_size = emscripten_get_heap_size();
-  EM_ASM({"globalThis.oldheap = HEAPU8;"});
+  EM_ASM({"globalThis.oldheap = HEAP8;"});
   assert(val::global("oldheap")["byteLength"].as<size_t>() == old_size);
   emscripten_resize_heap(old_size + EMSCRIPTEN_PAGE_SIZE);
   assert(emscripten_get_heap_size() > old_size);
-  // HEAPU8 on the module should now be rebound, and our oldheap should be
+  // HEAP8 on the module should now be rebound, and our oldheap should be
   // detached
-  assert(val::module_property("HEAPU8")["byteLength"].as<size_t>() > old_size);
+  assert(val::module_property("HEAP8")["byteLength"].as<size_t>() > old_size);
   assert(val::global("oldheap")["byteLength"].as<size_t>() == 0);
 }
 
