@@ -53,11 +53,6 @@ ASAN_C_HELPERS = [
 ]
 
 
-def write_output_file(outfile, module):
-  for chunk in module:
-    outfile.write(chunk)
-
-
 def maybe_disable_filesystem(imports):
   """Disables filesystem if only a limited subset of syscalls is used.
 
@@ -161,15 +156,26 @@ def update_settings_glue(wasm_file, metadata, base_metadata):
 
 
 def apply_static_code_hooks(forwarded_json, code):
-  code = shared.do_replace(code, '<<< ATPRERUNS >>>', str(forwarded_json['ATPRERUNS']))
-  code = shared.do_replace(code, '<<< ATINITS >>>', str(forwarded_json['ATINITS']))
-  code = shared.do_replace(code, '<<< ATPOSTCTORS >>>', str(forwarded_json['ATPOSTCTORS']))
+  def inject_code_hooks(name):
+    nonlocal code
+    hook_code = forwarded_json[name]
+    if hook_code:
+      hook_code = f'// Begin {name} hooks\n  {hook_code}\n  // End {name} hooks'
+    else:
+      hook_code = f'// No {name} hooks'
+    code = code.replace(f'<<< {name} >>>', hook_code)
+
+  inject_code_hooks('ATMODULES')
+  inject_code_hooks('ATPRERUNS')
+  inject_code_hooks('ATINITS')
+  inject_code_hooks('ATPOSTCTORS')
   if settings.HAS_MAIN:
-    code = shared.do_replace(code, '<<< ATMAINS >>>', str(forwarded_json['ATMAINS']))
+    inject_code_hooks('ATMAINS')
   if not settings.MINIMAL_RUNTIME or settings.HAS_MAIN:
-    code = shared.do_replace(code, '<<< ATPOSTRUNS >>>', str(forwarded_json['ATPOSTRUNS']))
+    inject_code_hooks('ATPOSTRUNS')
     if settings.EXIT_RUNTIME:
-      code = shared.do_replace(code, '<<< ATEXITS >>>', str(forwarded_json['ATEXITS']))
+      inject_code_hooks('ATEXITS')
+
   return code
 
 
@@ -402,13 +408,6 @@ def emscript(in_wasm, out_wasm, outfile_js, js_syms, finalize=True, base_metadat
 
   report_missing_exports(forwarded_json['librarySymbols'])
 
-  if settings.MINIMAL_RUNTIME:
-    # In MINIMAL_RUNTIME, atinit exists in the postamble part
-    post = apply_static_code_hooks(forwarded_json, post)
-  else:
-    # In regular runtime, atinits etc. exist in the preamble part
-    pre = apply_static_code_hooks(forwarded_json, pre)
-
   asm_const_pairs = ['%s: %s' % (key, value) for key, value in asm_consts]
   if asm_const_pairs or settings.MAIN_MODULE:
     pre += 'var ASM_CONSTS = {\n  ' + ',  \n '.join(asm_const_pairs) + '\n};\n'
@@ -430,22 +429,21 @@ def emscript(in_wasm, out_wasm, outfile_js, js_syms, finalize=True, base_metadat
     function_exports['asyncify_start_rewind'] = webassembly.FuncType([webassembly.Type.I32], [])
     function_exports['asyncify_stop_rewind'] = webassembly.FuncType([], [])
 
-  with open(outfile_js, 'w', encoding='utf-8') as out:
-    out.write(pre)
-    pre = None
+  parts = [pre]
+  receiving = create_receiving(function_exports)
+  if settings.WASM_ESM_INTEGRATION:
+    sending = create_sending(metadata, forwarded_json['librarySymbols'])
+    parts += [sending, receiving]
+  else:
+    parts += create_module(receiving, metadata, global_exports, forwarded_json['librarySymbols'])
+  parts.append(post)
 
-    receiving = create_receiving(function_exports)
+  full_js_module = ''.join(parts)
+  full_js_module = apply_static_code_hooks(forwarded_json, full_js_module)
+  utils.write_file(outfile_js, full_js_module)
 
-    module = create_module(receiving, metadata, global_exports, forwarded_json['librarySymbols'])
-
-    metadata.library_definitions = forwarded_json['libraryDefinitions']
-
-    write_output_file(out, module)
-
-    out.write(post)
-    module = None
-
-    return metadata
+  metadata.library_definitions = forwarded_json['libraryDefinitions']
+  return metadata
 
 
 @ToolchainProfiler.profile()
@@ -627,12 +625,16 @@ def create_tsd_exported_runtime_methods(metadata):
   js_doc_file = in_temp('jsdoc.js')
   tsc_output_file = in_temp('jsdoc.d.ts')
   utils.write_file(js_doc_file, js_doc)
-  tsc = shutil.which('tsc')
-  if tsc:
+  tsc = shared.get_npm_cmd('tsc', missing_ok=True)
+  # Prefer the npm install'd version of tsc since we know that one is compatible
+  # with emscripten output.
+  if not tsc:
+    # Fall back to tsc in the user's PATH.
+    tsc = shutil.which('tsc')
+    if not tsc:
+      exit_with_error('tsc executable not found in node_modules or in $PATH')
     # Use the full path from the which command so windows can find tsc.
     tsc = [tsc]
-  else:
-    tsc = shared.get_npm_cmd('tsc')
   cmd = tsc + ['--outFile', tsc_output_file,
                '--skipLibCheck', # Avoid checking any of the user's types e.g. node_modules/@types.
                '--declaration',
@@ -851,6 +853,13 @@ def create_sending(metadata, library_symbols):
           send_items_map[demangled] = f
 
   sorted_items = sorted(send_items_map.items())
+
+  if settings.WASM_ESM_INTEGRATION:
+    elems = []
+    for k, v in sorted_items:
+      elems.append(f'{v} as {k}')
+    return f"export {{ {', '.join(elems)} }};\n\n"
+
   prefix = ''
   if settings.MAYBE_CLOSURE_COMPILER:
     # This prevents closure compiler from minifying the field names in this
@@ -875,6 +884,7 @@ def make_export_wrappers(function_exports):
   assert not settings.MINIMAL_RUNTIME
 
   wrappers = []
+  decls = []
 
   def install_wrapper(sym):
     # The emscripten stack functions are called very early (by writeStackCookie) before
@@ -892,19 +902,22 @@ def make_export_wrappers(function_exports):
   for name, types in function_exports.items():
     nargs = len(types.params)
     mangled = asmjs_mangle(name)
-    wrapper = 'var %s = ' % mangled
+    wrapper = f'var {mangled} = '
 
     # TODO(sbc): Can we avoid exporting the dynCall_ functions on the module.
     should_export = settings.EXPORT_KEEPALIVE and mangled in settings.EXPORTED_FUNCTIONS
-    if (name.startswith('dynCall_') and settings.MODULARIZE != 'instance') or should_export:
-      if settings.MODULARIZE == 'instance':
-        # Update the export declared at the top level.
-        wrapper += f" __exp_{mangled} = "
+    if name.startswith('dynCall_') and settings.MODULARIZE != 'instance':
+      should_export = True
+    exported = ''
+    if settings.MODULARIZE == 'instance':
+      if should_export:
+        decls.append(f'export var {mangled};')
       else:
-        exported = "Module['%s'] = " % mangled
-    else:
-      exported = ''
-    wrapper += exported
+        decls.append(f'var {mangled};')
+      wrapper = f'  {mangled} = '
+    elif should_export:
+      exported = "Module['%s'] = " % mangled
+      wrapper += exported
 
     if settings.ASSERTIONS and install_wrapper(name):
       # With assertions enabled we create a wrapper that are calls get routed through, for
@@ -920,10 +933,23 @@ def make_export_wrappers(function_exports):
       wrapper += f"wasmExports['{name}']"
 
     wrappers.append(wrapper)
+
+  if settings.MODULARIZE == 'instance':
+    wrappers.insert(0, 'function assignWasmExports() {')
+    wrappers.append('}')
+    wrappers = decls + wrappers
+
   return wrappers
 
 
 def create_receiving(function_exports):
+  if settings.WASM_ESM_INTEGRATION:
+    exports = [f'{f} as {asmjs_mangle(f)}' for f in function_exports]
+    exports.append('memory as wasmMemory')
+    exports.append('__indirect_function_table as wasmTable')
+    exports = ',\n  '.join(exports)
+    return f"import {{\n  {exports}\n}} from './{settings.WASM_BINARY_FILE}';\n\n"
+
   # When not declaring asm exports this section is empty and we instead programmatically export
   # symbols on the global object by calling exportWasmSymbols after initialization
   if not settings.DECLARE_ASM_MODULE_EXPORTS:
@@ -975,7 +1001,9 @@ function assignWasmImports() {
     module.append('var wasmImports = %s;\n' % sending)
 
   if not settings.MINIMAL_RUNTIME:
-    if settings.WASM_ASYNC_COMPILATION:
+    if settings.MODULARIZE == 'instance':
+      module.append("var wasmExports;\n")
+    elif settings.WASM_ASYNC_COMPILATION:
       if can_use_await():
         # In modularize mode the generated code is within a factory function.
         # This magic string gets replaced by `await createWasm`.  It needed to allow
