@@ -44,7 +44,7 @@ USE_NINJA = int(os.environ.get('EMCC_USE_NINJA', '0'))
 
 # A (fake) deterministic emscripten path to use in __FILE__ macro and debug info
 # to produce reproducible builds across platforms.
-DETERMINISITIC_PREFIX = '/emsdk/emscripten'
+DETERMINISTIC_PREFIX = '/emsdk/emscripten'
 
 
 def files_in_path(path, filenames):
@@ -58,7 +58,7 @@ def glob_in_path(path, glob_pattern, excludes=()):
   return sorted(f for f in files if os.path.basename(f) not in excludes)
 
 
-def get_base_cflags(force_object_files=False, preprocess=True):
+def get_base_cflags(build_dir, force_object_files=False, preprocess=True):
   # Always build system libraries with debug information.  Non-debug builds
   # will ignore this at link time because we link with `-strip-debug`.
   flags = ['-g', '-sSTRICT', '-Werror']
@@ -70,9 +70,19 @@ def get_base_cflags(force_object_files=False, preprocess=True):
       flags += ['-DEMSCRIPTEN_DYNAMIC_LINKING']
   if settings.MEMORY64:
     flags += ['-Wno-experimental', '-sMEMORY64=' + str(settings.MEMORY64)]
+
+  source_dir = utils.path_from_root()
+  relative_source_dir = os.path.relpath(source_dir, build_dir)
+  flags += [f'-ffile-prefix-map={source_dir}={DETERMINISTIC_PREFIX}',
+            f'-ffile-prefix-map={relative_source_dir}={DETERMINISTIC_PREFIX}',
+            f'-fdebug-compilation-dir={DETERMINISTIC_PREFIX}']
   return flags
 
 
+def get_build_dir():
+  return cache.get_path('build')
+
+
 def clean_env():
   # building system libraries and ports should be hermetic in that it is not
   # affected by things like EMCC_CFLAGS which the user may have set.
@@ -144,7 +154,7 @@ def create_lib(libname, inputs):
 
 
 def get_top_level_ninja_file():
-  return os.path.join(cache.get_path('build'), 'build.ninja')
+  return os.path.join(get_build_dir(), 'build.ninja')
 
 
 def run_ninja(build_dir):
@@ -462,7 +472,7 @@ class Library:
     self.build_dir = build_dir
 
     cflags = self.get_cflags()
-    asflags = get_base_cflags(preprocess=False)
+    asflags = get_base_cflags(self.build_dir, preprocess=False)
     input_files = self.get_files()
     ninja_file = os.path.join(build_dir, 'build.ninja')
     create_ninja_file(input_files, ninja_file, libname, cflags, asflags=asflags, customize_build_flags=self.customize_build_cmd)
@@ -491,7 +501,7 @@ class Library:
         # .s files are processed directly by the assembler.  In this case we can't pass
         # pre-processor flags such as `-I` and `-D` but we still want core flags such as
         # `-sMEMORY64`.
-        cmd += get_base_cflags(preprocess=False)
+        cmd += get_base_cflags(self.build_dir, preprocess=False)
       else:
         cmd += cflags
       cmd = self.customize_build_cmd(cmd, src)
@@ -546,7 +556,7 @@ class Library:
   def do_build(self, out_filename, generate_only=False):
     """Builds the library and returns the path to the file."""
     assert out_filename == self.get_path(absolute=True)
-    build_dir = os.path.join(cache.get_path('build'), self.get_base_name())
+    build_dir = os.path.join(get_build_dir(), self.get_base_name())
     if USE_NINJA:
       self.generate_ninja(build_dir, out_filename)
       if not generate_only:
@@ -581,16 +591,10 @@ class Library:
     Override and add any flags as needed to handle new variations.
     """
     cflags = self._inherit_list('cflags')
-    cflags += get_base_cflags(force_object_files=self.force_object_files)
+    cflags += get_base_cflags(self.build_dir, force_object_files=self.force_object_files)
 
     if self.includes:
       cflags += ['-I' + utils.path_from_root(i) for i in self._inherit_list('includes')]
-
-    source_dir = utils.path_from_root()
-    relative_source_dir = os.path.relpath(source_dir, self.build_dir)
-    cflags += [f'-ffile-prefix-map={source_dir}={DETERMINISITIC_PREFIX}',
-               f'-ffile-prefix-map={relative_source_dir}={DETERMINISITIC_PREFIX}',
-               f'-fdebug-compilation-dir={DETERMINISITIC_PREFIX}']
     return cflags
 
   def get_base_name_prefix(self):
@@ -1168,6 +1172,7 @@ class libc(MuslInternalLibrary,
           'pthread_attr_setscope.c',
           'pthread_attr_setstack.c',
           'pthread_attr_setstacksize.c',
+          'pthread_getattr_np.c',
           'pthread_getconcurrency.c',
           'pthread_getcpuclockid.c',
           'pthread_getschedparam.c',
